@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2004-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2004-2022 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -33,8 +33,8 @@ LinkWidget::~LinkWidget()
 UMLClassifier *LinkWidget::operationOwner()
 {
     UMLOperation *op = operation();
-    if (op == 0)
-        return 0;
+    if (op == nullptr)
+        return nullptr;
     return op->umlParent()->asUMLClassifier();
 }
 
@@ -48,9 +48,9 @@ UMLClassifier *LinkWidget::operationOwner()
 QString LinkWidget::operationText(UMLScene *scene)
 {
     UMLOperation *op = operation();
-    if (op == 0)
+    if (op == nullptr)
         return customOpText();
-    if (scene == 0)
+    if (scene == nullptr)
         scene = UMLApp::app()->currentView()->umlScene();
     Uml::SignatureType::Enum sigType;
     if (scene && scene->showOpSig())
@@ -71,7 +71,6 @@ void LinkWidget::resetTextPositions()
 
 /**
  * Motivated by FloatingTextWidget::showPropertiesDialog()
- * Only applies to AssociationWidget.
  */
 bool LinkWidget::showPropertiesDialog()
 {
@@ -108,7 +107,7 @@ QString LinkWidget::sequenceNumber() const
  */
 bool LinkWidget::loadFromXMI(QDomElement &qElement)
 {
-    m_SequenceNumber = qElement.attribute(QLatin1String("seqnum"));
+    m_SequenceNumber = qElement.attribute(QStringLiteral("seqnum"));
     return true;
 }
 
@@ -117,5 +116,5 @@ bool LinkWidget::loadFromXMI(QDomElement &qElement)
  */
 void LinkWidget::saveToXMI(QXmlStreamWriter& writer)
 {
-    writer.writeAttribute(QLatin1String("seqnum"), m_SequenceNumber);
+    writer.writeAttribute(QStringLiteral("seqnum"), m_SequenceNumber);
 }
