@@ -12,10 +12,10 @@
 
 void TestPackage::test_appendClassesAndInterfaces()
 {
-    UMLPackage p("package");
-    UMLClassifier c1("class A");
-    UMLClassifier c2("class B");
-    UMLClassifier c3("class C");
+    UMLPackage p(QStringLiteral("package"));
+    UMLClassifier c1(QStringLiteral("class A"));
+    UMLClassifier c2(QStringLiteral("class B"));
+    UMLClassifier c3(QStringLiteral("class C"));
     p.addObject(&c1);
     p.addObject(&c2);
     p.addObject(&c3);
@@ -29,16 +29,16 @@ typedef TestUML<UMLPackage, const QString &> TestUMLPackage;
 
 void TestPackage::test_saveAndLoad()
 {
-    UMLPackage parent("parent");
-    TestUMLPackage p1("Package");
+    UMLPackage parent(QStringLiteral("parent"));
+    TestUMLPackage p1(QStringLiteral("Package"));
     p1.setUMLPackage(&parent);
-    UMLClassifier c1("Test A");
+    UMLClassifier c1(QStringLiteral("Test A"));
     c1.setUMLPackage(&p1);
-    UMLClassifier c2("Test B");
+    UMLClassifier c2(QStringLiteral("Test B"));
     c2.setUMLPackage(&p1);
     p1.addObject(&c1);
     p1.addObject(&c2);
-    p1.setStereotypeCmd("test");
+    p1.setStereotypeCmd(QStringLiteral("test"));
     QString save = p1.testSave1();
     //p1.testDump("save");
     TestUMLPackage p2;
